@@ -8,6 +8,7 @@
 
 #include "documentmanager.h"
 #include "favoritelocationmodel.h"
+#include "healthcertificatemanager.h"
 #include "livedata.h"
 #include "livedatamanager.h"
 #include "logging.h"
@@ -94,6 +95,17 @@ void Exporter::exportFavoriteLocations(const FavoriteLocationModel* favLocModel)
     }
 }
 
+void Exporter::exportHealthCertificates(const HealthCertificateManager *healthCertMgr)
+{
+    for (int i = 0; i < healthCertMgr->rowCount(); ++i) {
+        const auto idx = healthCertMgr->index(i, 0);
+        m_file->addCustomData(
+            QStringLiteral("org.kde.itinerary/health-certificates"),
+            healthCertMgr->data(idx, HealthCertificateManager::StorageIdRole).toString(),
+            healthCertMgr->data(idx, HealthCertificateManager::RawDataRole).toByteArray());
+    }
+}
+
 void Exporter::exportLiveData()
 {
     for (const auto &id : LiveData::listAll()) {
@@ -179,6 +191,15 @@ void Importer::importFavoriteLocations(FavoriteLocationModel *favLocModel)
     }
 }
 
+void Importer::importHealthCertificates(HealthCertificateManager *healthCertMgr)
+{
+    const auto domain = QStringLiteral("org.kde.itinerary/health-certificates");
+    const auto certIds = m_file->listCustomData(domain);
+    for (const auto &certId : certIds) {
+        healthCertMgr->importCertificate(m_file->customData(domain, certId));
+    }
+}
+
 void Importer::importLiveData(LiveDataManager *liveDataMgr)
 {
     const auto ids = m_file->listCustomData(QStringLiteral("org.kde.itinerary/live-data"));
