@@ -211,6 +211,7 @@ int main(int argc, char **argv)
     QGuiApplication app(argc, argv);
     QQuickStyle::setStyle(QStringLiteral("Material"));
 #else
+    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
     QApplication app(argc, argv); // for native file dialogs
 
     // Default to org.kde.desktop style unless the user forces another style
@@ -219,7 +220,7 @@ int main(int argc, char **argv)
     }
 #endif
     QGuiApplication::setApplicationDisplayName(i18n("KDE Itinerary"));
-    QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("itinerary")));
+    QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.itinerary")));
 
     auto aboutData = KAboutData::applicationData();
     aboutData.setProductName("KDE Itinerary/general"); // Bugzilla product/component name
