@@ -15,6 +15,7 @@
 #include "transfer.h"
 #include "transfermanager.h"
 
+#include <KItinerary/DocumentUtil>
 #include <KItinerary/Flight>
 #include <KItinerary/LocationUtil>
 #include <KItinerary/SortUtil>
@@ -530,7 +531,11 @@ bool TimelineDelegateController::connectionWarning() const
     const auto prevArrDt = std::max(SortUtil::endDateTime(prevRes), prevArr.expectedArrivalTime());
 
     const auto curDepDt = std::max(SortUtil::startDateTime(curRes), departure().expectedDepartureTime());
-    return curDepDt < prevArrDt;
+    if (curDepDt.isValid() && prevArrDt.isValid()) {
+        return curDepDt < prevArrDt;
+    }
+
+    return false;
 }
 
 bool TimelineDelegateController::isCanceled() const
@@ -686,4 +691,23 @@ QJSValue TimelineDelegateController::departureMapArguments() const
     return args;
 }
 
+int TimelineDelegateController::documentCount() const
+{
+    if (!m_resMgr || m_batchId.isEmpty()) {
+        return 0;
+    }
+
+    QSet<QString> allDocIds;
+    const auto resIds = m_resMgr->reservationsForBatch(m_batchId);
+    for (const auto &resId : resIds) {
+        const auto res = m_resMgr->reservation(resId);
+        const auto docIds = DocumentUtil::documentIds(res);
+        for (const auto &docId : docIds) {
+            // TODO we could check if actually have the document first?
+            allDocIds.insert(docId.toString());
+        }
+    }
+    return allDocIds.size();
+}
+
 #include "moc_timelinedelegatecontroller.cpp"
